@@ -6,8 +6,8 @@ from django.template import Context, TemplateDoesNotExist
 from django.template.loader import select_template
 from django.utils import translation
 
-from mail_factory import exceptions
-from mail_factory.messages import EmailMultiRelated
+from . import exceptions
+from .messages import EmailMultiRelated
 
 
 class BaseMail(object):
@@ -50,12 +50,9 @@ class BaseMail(object):
 
     def get_attachments(self, attachments):
         """Return the attachments."""
-        if attachments:
-            return attachments
+        return attachments or []
 
-        return []
-
-    def get_template_part(self, part):
+    def get_template_part(self, part, lang=None):
         """Return a mail part
 
           * subject.txt
@@ -70,7 +67,7 @@ class BaseMail(object):
         """
         templates = []
         # 1/ localized: mails/invitation_code/fr/
-        localized = join('mails', self.template_name, self.lang, part)
+        localized = join('mails', self.template_name, lang or self.lang, part)
         templates.append(localized)
 
         # 2/ fallback: mails/invitation_code/
@@ -80,7 +77,7 @@ class BaseMail(object):
         # return the list of templates path candidates
         return templates
 
-    def _render_part(self, part):
+    def _render_part(self, part, lang=None):
         """Render a mail part against the mail context.
 
         Part can be:
@@ -90,30 +87,31 @@ class BaseMail(object):
           * body.html
 
         """
-        tpl = select_template(self.get_template_part(part))
+        tpl = select_template(self.get_template_part(part, lang=lang))
         cur_lang = translation.get_language()
         try:
-            translation.activate(self.lang)
+            translation.activate(lang or self.lang)
             rendered = tpl.render(self.context)
         finally:
             translation.activate(cur_lang)
         return rendered.strip()
 
-    def create_email_msg(self, emails, from_email=None):
+    def create_email_msg(self, emails, attachments=None, from_email=None,
+                         lang=None, message_class=EmailMultiRelated):
         """Create an email message instance."""
 
         from_email = from_email or settings.DEFAULT_FROM_EMAIL
-        subject = self._render_part('subject.txt').strip()
+        subject = self._render_part('subject.txt', lang=lang).strip()
         try:
-            body = self._render_part('body.txt')
+            body = self._render_part('body.txt', lang=lang)
         except TemplateDoesNotExist:
             body = ''
         try:
-            html_content = self._render_part('body.html')
+            html_content = self._render_part('body.html', lang=lang)
         except TemplateDoesNotExist:
             html_content = None
 
-        msg = EmailMultiRelated(
+        msg = message_class(
             subject, body, from_email, emails,
             headers={'Reply-To': getattr(settings,
                                          "SUPPORT_EMAIL",
@@ -121,12 +119,6 @@ class BaseMail(object):
         if html_content:
             msg.attach_alternative(html_content, 'text/html')
 
-        return msg
-
-    def send(self, emails, attachments, from_email=None):
-        """Create the message and send it to emails."""
-        msg = self.create_email_msg(emails, from_email=from_email)
-
         attachments = self.get_attachments(attachments)
 
         if attachments:
@@ -136,8 +128,16 @@ class BaseMail(object):
                         msg.attach_related_file(filepath, mimetype, filename)
                     else:
                         msg.attach(filename, attachment.read(), mimetype)
+        return msg
 
-        msg.send()
+    def send(self, emails, attachments=None, from_email=None):
+        """Create the message and send it to emails."""
+        msg = self.create_email_msg(emails,
+                                    attachments=attachments,
+                                    from_email=from_email) \
+                  .send()
+
+        return msg
 
     def mail_admins(self, attachments=None, from_email=None):
         """Send email to admins."""
